(function () {
    'use strict'
    angular.module('Corporativo.Login', ['Corporativo.Core']);
})();

(function () {
    'use strict'
    angular.module('Corporativo.Login').service('LoginServices', LoginServices);
    LoginServices.$inject = ['$log', '$http', '$q', 'UsuarioService', 'RedireccionServices', 'StorageService', 'MS', '$cookies'];
    function LoginServices($log, $http, $q, Usuario, Redireccion, Storage, MS, $cookies) {
        let service = this;
        service.entrar = entrar;
        service.salir = salir;
        const dominio = MS.ORQ.ip + MS.ORQ.prefijo;
        
        function entrar(cuerpo) {
            return $http.post(dominio + "/get", cuerpo).then(procesarUsuario, error);
        }

        function salir() {
            Usuario.remover();
            Redireccion.login();
        }


        function procesarUsuario(res) { 
            if(res.data.datos){
                Usuario.info.clave = res.config.data.clave;
                Usuario.info.usuario = res.config.data.usuario;
                Usuario.info.claveRol = res.data.datos.claveRol;
                Usuario.info.idPersona = res.data.datos.idPersona;
                Usuario.info.negocio = res.data.datos.negocio;
                Usuario.info.rolSecom = res.data.datos.rolSecom;
                Usuario.info.idSesion = res.data.datos.idSesion;
                $log.info(angular.copy(res)); return res;
            }
        }
        function error(err) { return $q.reject(err.data.descripcionError) }
    }
})();

(function () {
    'use strict'
    angular.module('Corporativo.Login').controller('LoginCtrl', LoginCtrl);
    LoginCtrl.$inject = ['$log', 'StorageService', 'LoginServices', 'RedireccionServices', 'UsuarioService', '$cookies', '$timeout'];
    function LoginCtrl($log, Storage, Login, Redireccion, Usuario, $cookies, $timeout) {
        let vm = this;
        vm.contrasenia = "";
        vm.usuario = "";
        vm.login = "";
        vm.rutaInicioSesion = "/sites/Asesores/login";
        vm.limpiaValores = limpiaValores;
   
        //funciones
        vm.acceso = acceso;
    
        boot();
        function boot() {
            let detalleSesion = Storage.obtener("detalleSesion", true);
            if (detalleSesion) {
                $log.error(detalleSesion);
                vm.mensaje = detalleSesion.data.sesion;
            }
        }

        function limpiaValores() {
        
            vm.mensajeModal = "";
        }

        function acceso() {
            vm.mensaje = "";
            if (vm.contrasenia != undefined)
                if (vm.contrasenia.includes(" ")) {
                    vm.mensaje = "Validar datos ingresados";
                    vm.contrasenia = "";
                } else {
                    if (vm.usuario && vm.contrasenia && (vm.contrasenia.length >= 8)) {
                        vm.modal = true;
                        let clavee = "";
                        let clave = vm.usuario.split('');
                        for (let e = 0; e < clave.length; e++) {
                            if(clave[e] == 0 || clave[e] == 1 || clave[e] == 2 || clave[e] == 3 || clave[e] == 4 || clave[e] == 5 || clave[e] == 6 || clave[e] == 7 || clave[e] == 8 || clave[e] == 9){
                                if(clavee==""){
                                    clavee = clave[e];
                                }else{
                                    clavee = clavee+""+clave[e];
                                }
                            }
                        }
                        let cuerpo = { usuario: vm.usuario, password: vm.contrasenia, clave: clavee }
                        Login.entrar(cuerpo).then(Redireccion.entrar, error);
                    } else if (vm.contrasenia.length < 8 && vm.usuario) {
                        vm.contrasenia = "";
                        vm.mensaje = "El tama\u00f1o de la contrase\u00f1a debe ser de 8 a 16 caracteres";
                    } else {
                        vm.mensaje = "Usuario/Contrase\u00f1a requerido";
                    }
                }

        }


        function error(err) {
            vm.contrasenia = "";
            if (err.length >= 50 || !err.length) vm.mensaje = "No se puede ingresar por el momento, intentelo m\u00E1s tarde.";
            else vm.mensaje = err;
            $timeout(function () { vm.modal = false; }, 500);
        }

    }
})();